NotificationEvent class

The parameter passed into the onnotificationclick handler, the NotificationEvent interface represents a notification click event that is dispatched on the ServiceWorkerGlobalScope of a ServiceWorker.

Inheritance

Properties

action → String?
Returns the string ID of the notification button the user clicked. This value returns undefined if the user clicked the notification somewhere other than an action button, or the notification does not have a button.
no setter
bubbles → bool?
no setterinherited
cancelable → bool?
no setterinherited
composed → bool?
no setterinherited
currentTarget → EventTarget?
no setterinherited
defaultPrevented → bool
no setterinherited
eventPhase → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isTrusted → bool?
no setterinherited
matchingTarget → Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
notification → Notification?
Returns a Notification object representing the notification that was clicked to fire the event.
no setter
path → List<EventTarget>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → EventTarget?
no setterinherited
timeStamp → double?
no setterinherited
type → String
no setterinherited

Methods

composedPath() → List<EventTarget>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() → String
A string representation of this object.
inherited
waitUntil(Future future) → void
Extends the lifetime of the event. It is intended to be called in the install EventHandler for the installing worker and on the active EventHandler for the active worker.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited