PushManager class

The PushManager interface provides a way to receive notifications from third-party servers as well as request URLs for push notifications. This interface has replaced functionality offered by the obsolete PushRegistrationManager.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSubscription() → Future<PushSubscription?>
Returns a promise that resolves to a PushSubscription details of the retrieved push subscription.
hasPermission() → Future<String>
Returns a promise that resolves to the PushPermissionStatus of the requesting webapp, which will be one of granted, denied, or default.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
permissionState([PushSubscriptionOptions? options]) → Future<String>
Returns a promise that resolves to the PushPermissionStatus of the requesting webapp, which will be one of granted, denied, or prompt.
subscribe([PushSubscriptionOptions? options]) → Future<PushSubscription>
Returns a promise that resolves to a PushSubscription with details of a new push subscription.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited