PushSubscription class

The PushSubscription interface provides a subcription's URL endpoint and subscription ID.

Properties

endpoint → dynamic
The endpoint associated with the push subscription.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKey(String name) → ByteBuffer?
Returns a ByteBuffer representing a client public key, which can then be sent to a server and used in encrypting push message data.
getKeysAsString() → Map<String, String>
Similar to getKey, it returns the client public keys, encoded as String.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unsubscribe() → Future<bool>
Resolves to a Boolean when the current subscription is successfully unsubscribed.

Operators

operator ==(Object other) → bool
The equality operator.
inherited