PushSubscriptionOptions class abstract

Object containing optional subscribe parameters.

Annotations

Constructors

PushSubscriptionOptions({bool? userVisibleOnly, Uint8List? applicationServerKey})
factory

Properties

applicationServerKey ↔ Uint8List
A public key your push server will use to send messages to client apps via a push server. This value is part of a signing key pair generated by your application server and usable with elliptic curve digital signature (ECDSA) over the P-256 curve.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVisibleOnly ↔ bool
A boolean indicating that the returned push subscription will only be used for messages whose effect is made visible to the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited